summaryrefslogtreecommitdiff
path: root/libdocument/ev-module.c
diff options
context:
space:
mode:
Diffstat (limited to 'libdocument/ev-module.c')
-rw-r--r--libdocument/ev-module.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libdocument/ev-module.c b/libdocument/ev-module.c
index 330da2cc..1a147eff 100644
--- a/libdocument/ev-module.c
+++ b/libdocument/ev-module.c
@@ -1,6 +1,6 @@
/*
* ev-module.c
* This file is part of Evince
*
* Copyright (C) 2005 - Paolo Maggi
*
@@ -36,7 +36,7 @@
* $Id: gedit-module.c 5367 2006-12-17 14:29:49Z pborelli $
*/
-/* Modified by evince team */
+/* Modified by atril team */
#include "config.h"
@@ -82,7 +82,7 @@ ev_module_load (GTypeModule *gmodule)
}
/* extract symbols from the lib */
- if (!g_module_symbol (module->library, "register_evince_backend",
+ if (!g_module_symbol (module->library, "register_atril_backend",
(void *) &register_func)) {
g_warning ("%s", g_module_error ());
g_module_close (module->library);
@@ -93,7 +93,7 @@ ev_module_load (GTypeModule *gmodule)
/* symbol can still be NULL even though g_module_symbol
* returned TRUE */
if (!register_func) {
- g_warning ("Symbol 'register_evince_backend' should not be NULL");
+ g_warning ("Symbol 'register_atril_backend' should not be NULL");
g_module_close (module->library);
return FALSE;
@@ -102,7 +102,7 @@ ev_module_load (GTypeModule *gmodule)
module->type = register_func (gmodule);
if (module->type == 0) {
- g_warning ("Invalid evince backend contained by module %s", module->path);
+ g_warning ("Invalid atril backend contained by module %s", module->path);
return FALSE;
}
@@ -1,6 +1,6 @@
/*
* ev-module.c
- * This file is part of Evince
+ * This file is part of Atril
*
* Copyright (C) 2005 - Paolo Maggi